Erlang Binary Term Format for Python
====================================

|Build Status|

Provides all encoding and decoding for the Erlang Binary Term Format (as
defined at http://erlang.org/doc/apps/erts/erl_ext_dist.html) in a
single Python module.


Tests
-----

::

    python setup.py test

Author
------

Michael Truog (mjtruog at protonmail dot com)

License
-------

MIT License

.. |Build Status| image:: https://secure.travis-ci.org/okeuday/erlang_py.png?branch=master
   :target: http://travis-ci.org/okeuday/erlang_py
